import { PublicKey } from '@solana/web3.js';
import { Group } from './accounts/group';
import { MangoAccount } from './accounts/mangoAccount';
import { MangoClient } from './client';
export interface LiqorPriceImpact {
    Coin: string;
    'Oracle Price': number;
    'On-Chain Price': number;
    'Future Price': number;
    'V4 Liq Fee': number;
    Liabs: number;
    'Liabs slippage': number;
    Assets: number;
    'Assets Slippage': number;
}
export interface PerpPositionsToBeLiquidated {
    Market: string;
    Price: number;
    'Future Price': number;
    'Notional Position': number;
}
export interface AccountEquity {
    Account: PublicKey;
    Equity: number;
}
export interface Risk {
    assetRally: {
        title: string;
        data: LiqorPriceImpact[];
    };
    assetDrop: {
        title: string;
        data: LiqorPriceImpact[];
    };
    perpRally: {
        title: string;
        data: PerpPositionsToBeLiquidated[];
    };
    perpDrop: {
        title: string;
        data: PerpPositionsToBeLiquidated[];
    };
    marketMakerEquity: {
        title: string;
        data: AccountEquity[];
    };
    liqorEquity: {
        title: string;
        data: AccountEquity[];
    };
}
export declare function computePriceImpactOnJup(amount: string, inputMint: string, outputMint: string): Promise<{
    outAmount: number;
    priceImpactPct: number;
}>;
export declare function getPriceImpactForLiqor(group: Group, mangoAccounts: MangoAccount[]): Promise<LiqorPriceImpact[]>;
export declare function getPerpPositionsToBeLiquidated(group: Group, mangoAccounts: MangoAccount[]): Promise<PerpPositionsToBeLiquidated[]>;
export declare function getEquityForMangoAccounts(client: MangoClient, group: Group, mangoAccounts: PublicKey[]): Promise<AccountEquity[]>;
export declare function getRiskStats(client: MangoClient, group: Group, change?: number): Promise<Risk>;
//# sourceMappingURL=risk.d.ts.map